import{s as pe,n as fe,o as ge}from"../chunks/scheduler.7bc62968.js";import{S as ve,i as be,g as s,s as a,r as x,A as $e,h as r,f as n,c as o,j as he,u as k,x as l,k as me,y as we,a as i,v as M,d as H,t as C,w as P}from"../chunks/index.2f8492b0.js";import{H as z}from"../chunks/Heading.14fb2476.js";function Ae(ee){let c,I,E,B,d,q,u,S,h,te="Autoencoders are a class of neural networks primarily used for unsupervised learning and dimensionality reduction. The fundamental idea behind autoencoders is to encode input data into a lower-dimensional representation and then decode it back to the original data, aiming to minimize the reconstruction error. The basic architecture of an autoencoder consists of two main components - <code>the encoder</code> and <code>the decoder</code>",U,m,ne="<li><strong>Encoder:</strong> The encoder is responsible for transforming the input data into a compressed or latent representation. It typically consists of one or more layers of neurons that progressively reduce the dimensions of the input.</li> <li><strong>Decoder:</strong> The decoder, on the other hand, takes the compressed representation produced by the encoder and attempts to reconstruct the original input data. Like the encoder, it often consists of one or more layers, but in the reverse order, gradually increasing the dimensions.</li>",R,p,ie='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/generative_models/autoencoder.png" alt="Vanilla Autoencoder Image - Lilian Weng Blog"/>',j,f,ae=`This encoder model consists of an encoder network (represented as $$\\g<em>\\phi$$) and a decoder network (represented as $$f</em>\\theta$$).
The low-dimensional representation is learned in the bottleneck layer as $$z$$ and the reconstructed output is represented as $$x’=f<em>\\theta(g</em>\\phi(x))$$ with the goal as $$x\\approx x’$$.
A common loss function used in such vanilla autoencoders is $$L(\\theta, \\phi) = \\frac{1}{n}\\sum<em>{i=1}^n (\\mathbf{x}^{(i)} - f</em>\\theta(g_\\phi(\\mathbf{x}^{(i)})))^2$$ with tries to minimize the error between the original image and the reconstructed one and is also known as the <code>reconstruction loss</code>
Autoencoders are useful for tasks such as data denoising, feature learning, and compression. However, traditional autoencoders lack the probabilistic nature that makes VAEs particularly intriguing and also useful for generational tasks`,G,g,O,v,oe="Variational Autoencoders (VAEs) address some of the limitations of traditional autoencoders by introducing a <code>probabilistic approach</code> to encoding and decoding. The motivation behind VAEs lies in their ability to generate new data samples by sampling from a learned distribution in the latent space rather than from a latent vector as was the case with Vanilla Autoencoders which makes them suitable for generation tasks.",W,b,se="<li><strong>Probabilistic Nature:</strong> Unlike deterministic autoencoders, VAEs model the latent space as a probability distribution. This produces a probability distribution function over the input encodings instead of just a single fixed vector. This allows for a more nuanced representation of uncertainty in the data. The decoder then samples from this probability distribution.</li> <li><strong>Role of Latent Space:</strong> The latent space in VAEs serves as a continuous, structured representation of the input data. Since it is continuous by design, this allows for easy interpolation. Each point in the latent space corresponds to a potential output, enabling smooth transitions between different data points and also making sure that points which are closer to the latent space lead to similar generation</li>",F,$,re=`The concept can be elucidated through a straightforward example, as presented below. Encoders within a neural network are tasked with acquiring a representation of input images in the form of a vector. This vector encapsulates various features such as a subject’s smile, hair color, gender, age, etc., denoted as a vector akin to [0.4, 0.03, 0.032, …]. In this illustration, the focus is narrowed to a singular latent representation, specifically the attribute of a “smile.”
<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/generative_models/comparison.png" alt="Autoencoders vs VAEs - Sciforce Medium"/>
In the context of Vanilla Autoencoders (AE), the smile feature is encapsulated as a fixed, deterministic value. In contrast, Variational Autoencoders (VAEs) are deliberately crafted to encapsulate this feature as a probabilistic distribution. This design choice facilitates the introduction of variability in generated images by enabling the sampling of values from the specified probability distribution.`,K,w,N,A,le=`Understanding the mathematical concepts behind VAEs involves grasping the principles of probabilistic modeling and variational inference.
<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/generative_models/vae.png" alt="Variational Autoencoder - Lilian Weng Blog"/>`,D,T,ce="<li><strong>Probabilistic Modeling:</strong> In VAEs, the latent space is modeled as a probability distribution, often assumed to be a multivariate Gaussian. This distribution is parameterized by the mean and standard deviation vectors, which are outputs of the probabilistic encoder $$q<em>\\phi(z|x)$$. This comprosises of our learned representation $$z$$ which is further used to sample from the decoder as $$p</em>\\theta(x|z)$$</li> <li><strong>Loss Function:</strong> The loss function for VAEs comprises two components: the reconstruction loss (measuring how well the model reconstructs the input) similar to the vanilla autoencoders and the KL divergence (measuring how closely the learned distribution resembles a chosen prior distribution, usually gaussian). The combination of these components encourages the model to learn a latent representation that captures both the data distribution and the specified prior.</li> <li><strong>Encouraging Meaningful Latent Representations:</strong> By incorporating the KL divergence term into the loss function, VAEs are encouraged to learn a latent space where similar data points are closer, ensuring a meaningful and structured representation. The autoencoder’s loss function aims to minimize both the reconstruction loss and the latent loss. A smaller latent loss implies a limited encoding of information that would otherwise enhance the reconstruction loss. Consequently, the Variational Autoencoder (VAE) finds itself in a delicate balance between the latent loss and the reconstruction loss. This equilibrium becomes pivotal, as a <code>smaller latent loss</code> tends to result in generated images closely resembling those present in the training set but lacking in visual quality. Conversely, a <code>smaller reconstruction loss</code> leads to well-reconstructed images during training but hampers the generation of novel images that deviate significantly from the training set. Striking a harmonious balance between these two aspects becomes imperative to achieve desirable outcomes in both image reconstruction and generation.</li>",J,y,de="In summary, VAEs go beyond mere data reconstruction; they generate new samples and provide a probabilistic framework for understanding latent representations. The inclusion of probabilistic elements in the model’s architecture sets VAEs apart from traditional autoencoders. Compared to traditional autoencoders, VAEs provide a richer understanding of the data distribution, making them particularly powerful for generative tasks.",Q,L,X,V,ue='<li><a href="https://lilianweng.github.io/posts/2018-08-12-vae/" rel="nofollow">Lilian Weng’s Awesome Blog on Autoencoders</a></li> <li><a href="https://medium.com/sciforce/generative-models-under-a-microscope-comparing-vaes-gans-and-flow-based-models-344f20085d83" rel="nofollow">Generative models under a microscope: Comparing VAEs, GANs, and Flow-Based Models</a></li> <li><a href="https://medium.com/@rushikesh.shende/autoencoders-variational-autoencoders-vae-and-%CE%B2-vae-ceba9998773d" rel="nofollow">Autoencoders, Variational Autoencoders (VAE) and β-VAE</a></li>',Y,_,Z;return d=new z({props:{title:"Variational Autoencoders",local:"variational-autoencoders",headingTag:"h1"}}),u=new z({props:{title:"Introduction to Autoencoders",local:"introduction-to-autoencoders",headingTag:"h2"}}),g=new z({props:{title:"Variational Autoencoders (VAEs) Overview",local:"variational-autoencoders-vaes-overview",headingTag:"h2"}}),w=new z({props:{title:"Mathematics Behind VAEs",local:"mathematics-behind-vaes",headingTag:"h2"}}),L=new z({props:{title:"References",local:"references",headingTag:"h2"}}),{c(){c=s("meta"),I=a(),E=s("p"),B=a(),x(d.$$.fragment),q=a(),x(u.$$.fragment),S=a(),h=s("p"),h.innerHTML=te,U=a(),m=s("ul"),m.innerHTML=ne,R=a(),p=s("p"),p.innerHTML=ie,j=a(),f=s("p"),f.innerHTML=ae,G=a(),x(g.$$.fragment),O=a(),v=s("p"),v.innerHTML=oe,W=a(),b=s("ul"),b.innerHTML=se,F=a(),$=s("p"),$.innerHTML=re,K=a(),x(w.$$.fragment),N=a(),A=s("p"),A.innerHTML=le,D=a(),T=s("ul"),T.innerHTML=ce,J=a(),y=s("p"),y.textContent=de,Q=a(),x(L.$$.fragment),X=a(),V=s("ol"),V.innerHTML=ue,Y=a(),_=s("p"),this.h()},l(e){const t=$e("svelte-u9bgzb",document.head);c=r(t,"META",{name:!0,content:!0}),t.forEach(n),I=o(e),E=r(e,"P",{}),he(E).forEach(n),B=o(e),k(d.$$.fragment,e),q=o(e),k(u.$$.fragment,e),S=o(e),h=r(e,"P",{"data-svelte-h":!0}),l(h)!=="svelte-1vksmvl"&&(h.innerHTML=te),U=o(e),m=r(e,"UL",{"data-svelte-h":!0}),l(m)!=="svelte-d5442w"&&(m.innerHTML=ne),R=o(e),p=r(e,"P",{"data-svelte-h":!0}),l(p)!=="svelte-1pz9psz"&&(p.innerHTML=ie),j=o(e),f=r(e,"P",{"data-svelte-h":!0}),l(f)!=="svelte-krgvli"&&(f.innerHTML=ae),G=o(e),k(g.$$.fragment,e),O=o(e),v=r(e,"P",{"data-svelte-h":!0}),l(v)!=="svelte-howquo"&&(v.innerHTML=oe),W=o(e),b=r(e,"UL",{"data-svelte-h":!0}),l(b)!=="svelte-1bczhew"&&(b.innerHTML=se),F=o(e),$=r(e,"P",{"data-svelte-h":!0}),l($)!=="svelte-3nl3dr"&&($.innerHTML=re),K=o(e),k(w.$$.fragment,e),N=o(e),A=r(e,"P",{"data-svelte-h":!0}),l(A)!=="svelte-kly6w5"&&(A.innerHTML=le),D=o(e),T=r(e,"UL",{"data-svelte-h":!0}),l(T)!=="svelte-b9zcgj"&&(T.innerHTML=ce),J=o(e),y=r(e,"P",{"data-svelte-h":!0}),l(y)!=="svelte-8riv9g"&&(y.textContent=de),Q=o(e),k(L.$$.fragment,e),X=o(e),V=r(e,"OL",{"data-svelte-h":!0}),l(V)!=="svelte-o866ii"&&(V.innerHTML=ue),Y=o(e),_=r(e,"P",{}),he(_).forEach(n),this.h()},h(){me(c,"name","hf:doc:metadata"),me(c,"content",Te)},m(e,t){we(document.head,c),i(e,I,t),i(e,E,t),i(e,B,t),M(d,e,t),i(e,q,t),M(u,e,t),i(e,S,t),i(e,h,t),i(e,U,t),i(e,m,t),i(e,R,t),i(e,p,t),i(e,j,t),i(e,f,t),i(e,G,t),M(g,e,t),i(e,O,t),i(e,v,t),i(e,W,t),i(e,b,t),i(e,F,t),i(e,$,t),i(e,K,t),M(w,e,t),i(e,N,t),i(e,A,t),i(e,D,t),i(e,T,t),i(e,J,t),i(e,y,t),i(e,Q,t),M(L,e,t),i(e,X,t),i(e,V,t),i(e,Y,t),i(e,_,t),Z=!0},p:fe,i(e){Z||(H(d.$$.fragment,e),H(u.$$.fragment,e),H(g.$$.fragment,e),H(w.$$.fragment,e),H(L.$$.fragment,e),Z=!0)},o(e){C(d.$$.fragment,e),C(u.$$.fragment,e),C(g.$$.fragment,e),C(w.$$.fragment,e),C(L.$$.fragment,e),Z=!1},d(e){e&&(n(I),n(E),n(B),n(q),n(S),n(h),n(U),n(m),n(R),n(p),n(j),n(f),n(G),n(O),n(v),n(W),n(b),n(F),n($),n(K),n(N),n(A),n(D),n(T),n(J),n(y),n(Q),n(X),n(V),n(Y),n(_)),n(c),P(d,e),P(u,e),P(g,e),P(w,e),P(L,e)}}}const Te='{"title":"Variational Autoencoders","local":"variational-autoencoders","sections":[{"title":"Introduction to Autoencoders","local":"introduction-to-autoencoders","sections":[],"depth":2},{"title":"Variational Autoencoders (VAEs) Overview","local":"variational-autoencoders-vaes-overview","sections":[],"depth":2},{"title":"Mathematics Behind VAEs","local":"mathematics-behind-vaes","sections":[],"depth":2},{"title":"References","local":"references","sections":[],"depth":2}],"depth":1}';function ye(ee){return ge(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class _e extends ve{constructor(c){super(),be(this,c,ye,Ae,pe,{})}}export{_e as component};
